{% extends "admin/login.html" %}

{% load i18n %}

{% block content %}
{{ block.super }}
<a href="{% url 'admin:admin_sso_assignment_start' %}">{% trans "Log in using SSO" %}</a>
{% endblock content %}
